@@ -24,7 +24,7 @@
 #'   gene expression data) as well as the correlation structure between 
 #'   variables/nodes. Thus, all functions in the \code{NetRep} package have the 
 #'   following arguments: 
-#'   \itemize{
+#'   \describe{
 #'     \item{\code{network}: }{
 #'       a list of interaction networks, one for each dataset.
 #'     }
@@ -155,7 +155,7 @@
 #'   
 #'   The size of text labels can be modified by increasing or decreasing the
 #'   \code{cex.main}, \code{cex.lab}, and \code{cex.axis} arguments:
-#'   \itemize{
+#'   \describe{
 #'    \item{\code{cex.main}: }{controls the size of the plot title (specified 
 #'                            in the \code{main} argument).}
 #'    \item{\code{cex.lab}: }{controls the size of the axis labels on the
@@ -169,7 +169,7 @@
 #'   
 #'   The position of these labels can be changed through the following 
 #'   arguments:
-#'   \itemize{
+#'   \describe{
 #'    \item{\code{xaxt.line}: }{controls the distance from the plot the x-axis
 #'          tick labels are drawn on the \emph{module summary} bar plot.}
 #'    \item{\code{xlab.line}: }{controls the distance from the plot the x-axis 
@@ -200,7 +200,7 @@
 #'   
 #'   The size of the axis ticks can be changed by increasing or decreasing the
 #'   following arguments:
-#'   \itemize{
+#'   \describe{
 #'    \item{\code{xaxt.tck}: }{size of the x-axis tick labels as a multiple of
 #'          the height of the \emph{module summary} bar plot}
 #'    \item{\code{yaxt.tck}: }{size of the y-axis tick labels as a multiple of 
@@ -417,7 +417,7 @@ plotModule <- function(
   finput$networkEnv <- NULL
   
   # Flag for on.exit
-  anyDM <- any.disk.matrix(data[[loadedIdx]], correlation[[loadedIdx]], 
+  anyDM <- check.any.disk.matrix(data[[loadedIdx]], correlation[[loadedIdx]], 
                            network[[loadedIdx]])
   
   on.exit({
@@ -490,7 +490,7 @@ plotModule <- function(
   nNewSamples <- plotProps$nNewSamples
   
   # flag for on.exit
-  anyDM <- any.disk.matrix(data[[ti]], correlation[[ti]], network[[ti]])
+  anyDM <- check.any.disk.matrix(data[[ti]], correlation[[ti]], network[[ti]])
   
   if (ti != loadedIdx) {
     vCat(verbose && is.disk.matrix(correlation[[ti]]), 0, 
